==> Paws-0.34.tar.gz: Paws-0.34/lib/Paws/Shield/DescribeSubscription.pm <==

package Paws::Shield::DescribeSubscription;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeSubscription');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Shield::DescribeSubscriptionResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Shield::DescribeSubscription - Arguments for method DescribeSubscription on Paws::Shield

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeSubscription on the 
AWS Shield service. Use the attributes of this class
as arguments to method DescribeSubscription.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeSubscription.

As an example:

  $service_obj->DescribeSubscription(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeSubscription in L<Paws::Shield>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.46.tar.gz: Paws-0.46/lib/Paws/Shield/DescribeSubscription.pm <==

package Paws::Shield::DescribeSubscription;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeSubscription');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Shield::DescribeSubscriptionResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Shield::DescribeSubscription - Arguments for method DescribeSubscription on L<Paws::Shield>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeSubscription on the
L<AWS Shield|Paws::Shield> service. Use the attributes of this class
as arguments to method DescribeSubscription.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeSubscription.

=head1 SYNOPSIS

    my $shield = Paws->service('Shield');
    my $DescribeSubscriptionResponse = $shield->DescribeSubscription();

    # Results:
    my $Subscription = $DescribeSubscriptionResponse->Subscription;

    # Returns a L<Paws::Shield::DescribeSubscriptionResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/shield/DescribeSubscription>

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeSubscription in L<Paws::Shield>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
